@@ -7,8 +7,7 @@ size.
 
 if __name__ == '__main__':
     # Create a resizable webview window with minimum size constraints
-    webview.create_window("Minimum window size",
-                          "https://pywebview.flowrl.com/hello",
-                          width=800, height=600,
-                          resizable=True,
+    webview.create_window('Minimum window size',
+                          'https://pywebview.flowrl.com/hello',
                           min_size=(400, 200))
+    webview.start()
\ No newline at end of file
