@@ -6,4 +6,5 @@ This example demonstrates how to create a webview window.
 
 if __name__ == '__main__':
     # Create a standard webview window
-    webview.create_window('Simple browser', 'https://pywebview.flowrl.com/hello')
+    window = webview.create_window('Simple browser', 'https://pywebview.flowrl.com/hello')
+    webview.start()
