@@ -2,7 +2,7 @@ import os
 import webview
 
 """
-An example of serverless app architecture using webview.start() function
+An example of serverless app architecture
 """
 
 
@@ -19,11 +19,12 @@ class Api():
     def toggleItem(self, item):
         print('Toggled item %s' % item)
 
-    def toggleFullscreen(self, param):
-        webview.toggle_fullscreen()
+    def toggleFullscreen(self):
+        webview.windows[0].toggle_fullscreen()
 
 
 if __name__ == '__main__':
     api = Api()
-    webview.create_window('Todos magnificos', 'assets/index.html', js_api=api, min_size=(600, 450), debug=True)
+    webview.create_window('Todos magnificos', 'assets/index.html', js_api=api, min_size=(600, 450))
+    webview.start()
 
